@@ -26,10 +26,12 @@ def handler_decorator(handler):
     try:
       return handler(*args)
     except Exception as err:
+      print("sending error to sentry: ", os.environ['SENTRY_DSN'])
       sentry_sdk.capture_exception(err)
+      sentry_sdk.capture_message("hi decorator")
       return {
         "statusCode": 500,
-        "body": json.dumps({"error": err }),
+        "body": str(err),
       }
 
   return wrapper
\ No newline at end of file
